package com.muyu.authentication.controller;

import com.muyu.authentication.domain.Authentication;
import com.muyu.authentication.domain.req.AuthenticationEditReq;
import com.muyu.authentication.domain.req.AuthenticationQueryReq;
import com.muyu.authentication.domain.req.AuthenticationSaveReq;
import com.muyu.authentication.service.AuthenticationService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 认证Controller
 *
 * @author wan
 * @date 2024-05-29
 */
@Api(tags = "认证")
@RestController
@RequestMapping("/authentication")
public class AuthenticationController extends BaseController {
    @Autowired
    private AuthenticationService authenticationService;

    /**
     * 查询认证列表
     */
    @ApiOperation("获取认证列表")
    @RequiresPermissions("authentication:authentication:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Authentication>> list(AuthenticationQueryReq authenticationQueryReq) {
        startPage();
        List<Authentication> list = authenticationService.list(Authentication.queryBuild(authenticationQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出认证列表
     */
    @ApiOperation("导出认证列表")
    @RequiresPermissions("authentication:authentication:export")
    @Log(title = "认证", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Authentication authentication) {
        List<Authentication> list = authenticationService.list(authentication);
        ExcelUtil<Authentication> util = new ExcelUtil<Authentication>(Authentication.class);
        util.exportExcel(response, list, "认证数据");
    }

    /**
     * 获取认证详细信息
     */
    @ApiOperation("获取认证详细信息")
    @RequiresPermissions("authentication:authentication:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Authentication> getInfo(@PathVariable("id") Long id) {
        return Result.success(authenticationService.getById(id));
    }

    /**
     * 新增认证
     */
    @RequiresPermissions("authentication:authentication:add")
    @Log(title = "认证", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增认证")
    public Result<String> add(@RequestBody AuthenticationSaveReq authenticationSaveReq) {
        return toAjax(authenticationService.save(Authentication.saveBuild(authenticationSaveReq)));
    }

    /**
     * 修改认证
     */
    @RequiresPermissions("authentication:authentication:edit")
    @Log(title = "认证", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改认证")
    public Result<String> edit(@PathVariable Long id, @RequestBody AuthenticationEditReq authenticationEditReq) {
        return toAjax(authenticationService.updateById(Authentication.editBuild(id,authenticationEditReq)));
    }

    /**
     * 删除认证
     */
    @RequiresPermissions("authentication:authentication:remove")
    @Log(title = "认证", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除认证")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(authenticationService.removeBatchByIds(ids));
    }
}
