package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.CompanyService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.company.domain.Company;
import com.muyu.company.domain.req.CompanyQueryReq;
import com.muyu.company.domain.req.CompanySaveReq;
import com.muyu.company.domain.req.CompanyEditReq;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 企业Controller
 *
 * @author wan
 * @date 2024-05-29
 */
@Api(tags = "企业")
@RestController
@RequestMapping("/company")
public class CompanyController extends BaseController {
    @Autowired
    private CompanyService companyService;

    /**
     * 查询企业列表
     */
    @ApiOperation("获取企业列表")
    @RequiresPermissions("authentication:company:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Company>> list(CompanyQueryReq companyQueryReq) {
        startPage();
        List<Company> list = companyService.list(Company.queryBuild(companyQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出企业列表
     */
    @ApiOperation("导出企业列表")
    @RequiresPermissions("authentication:company:export")
    @Log(title = "企业", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Company company) {
        List<Company> list = companyService.list(company);
        ExcelUtil<Company> util = new ExcelUtil<Company>(Company.class);
        util.exportExcel(response, list, "企业数据");
    }

    /**
     * 获取企业详细信息
     */
    @ApiOperation("获取企业详细信息")
    @RequiresPermissions("authentication:company:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Company> getInfo(@PathVariable("id") Long id) {
        return Result.success(companyService.getById(id));
    }

    /**
     * 新增企业
     */
    @RequiresPermissions("authentication:company:add")
    @Log(title = "企业", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增企业")
    public Result<String> add(@RequestBody CompanySaveReq companySaveReq) {
        return toAjax(companyService.save(Company.saveBuild(companySaveReq)));
    }

    /**
     * 修改企业
     */
    @RequiresPermissions("authentication:company:edit")
    @Log(title = "企业", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改企业")
    public Result<String> edit(@PathVariable Long id, @RequestBody CompanyEditReq companyEditReq) {
        return toAjax(companyService.updateById(Company.editBuild(id,companyEditReq)));
    }

    /**
     * 删除企业
     */
    @RequiresPermissions("authentication:company:remove")
    @Log(title = "企业", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除企业")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(companyService.removeBatchByIds(ids));
    }
}
