package com.muyu.authentication.controller;

import com.muyu.authentication.service.LiberalService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.liberal.domain.Liberal;
import com.muyu.liberal.domain.req.LiberalEditReq;
import com.muyu.liberal.domain.req.LiberalQueryReq;
import com.muyu.liberal.domain.req.LiberalSaveReq;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 开通服务Controller
 *
 * @author wan
 * @date 2024-05-29
 */
@Api(tags = "开通服务")
@RestController
@RequestMapping("/liberal")
public class LiberalController extends BaseController {
    @Autowired
    private LiberalService liberalService;

    /**
     * 查询开通服务列表
     */
    @ApiOperation("获取开通服务列表")
    @RequiresPermissions("authentication:liberal:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Liberal>> list(LiberalQueryReq liberalQueryReq) {
        startPage();
        List<Liberal> list = liberalService.list(Liberal.queryBuild(liberalQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出开通服务列表
     */
    @ApiOperation("导出开通服务列表")
    @RequiresPermissions("authentication:liberal:export")
    @Log(title = "开通服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Liberal liberal) {
        List<Liberal> list = liberalService.list(liberal);
        ExcelUtil<Liberal> util = new ExcelUtil<Liberal>(Liberal.class);
        util.exportExcel(response, list, "开通服务数据");
    }

    /**
     * 获取开通服务详细信息
     */
    @ApiOperation("获取开通服务详细信息")
    @RequiresPermissions("authentication:liberal:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Liberal> getInfo(@PathVariable("id") Long id) {
        return Result.success(liberalService.getById(id));
    }

    /**
     * 新增开通服务
     */
    @RequiresPermissions("authentication:liberal:add")
    @Log(title = "开通服务", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增开通服务")
    public Result<String> add(@RequestBody LiberalSaveReq liberalSaveReq) {
        return toAjax(liberalService.save(Liberal.saveBuild(liberalSaveReq)));
    }

    /**
     * 修改开通服务
     */
    @RequiresPermissions("authentication:liberal:edit")
    @Log(title = "开通服务", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改开通服务")
    public Result<String> edit(@PathVariable Long id, @RequestBody LiberalEditReq liberalEditReq) {
        return toAjax(liberalService.updateById(Liberal.editBuild(id,liberalEditReq)));
    }

    /**
     * 删除开通服务
     */
    @RequiresPermissions("authentication:liberal:remove")
    @Log(title = "开通服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除开通服务")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(liberalService.removeBatchByIds(ids));
    }
}
