package com.muyu.authentication.controller;

import com.muyu.authentication.service.PayService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.pay.domain.Pay;
import com.muyu.pay.domain.req.PayEditReq;
import com.muyu.pay.domain.req.PayQueryReq;
import com.muyu.pay.domain.req.PaySaveReq;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 支付Controller
 *
 * @author wan
 * @date 2024-05-29
 */
@Api(tags = "支付")
@RestController
@RequestMapping("/pay")
public class PayController extends BaseController {
    @Autowired
    private PayService payService;

    /**
     * 查询支付列表
     */
    @ApiOperation("获取支付列表")
    @RequiresPermissions("authentication:pay:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Pay>> list(PayQueryReq payQueryReq) {
        startPage();
        List<Pay> list = payService.list(Pay.queryBuild(payQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出支付列表
     */
    @ApiOperation("导出支付列表")
    @RequiresPermissions("authentication:pay:export")
    @Log(title = "支付", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Pay pay) {
        List<Pay> list = payService.list(pay);
        ExcelUtil<Pay> util = new ExcelUtil<Pay>(Pay.class);
        util.exportExcel(response, list, "支付数据");
    }

    /**
     * 获取支付详细信息
     */
    @ApiOperation("获取支付详细信息")
    @RequiresPermissions("authentication:pay:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Pay> getInfo(@PathVariable("id") Long id) {
        return Result.success(payService.getById(id));
    }

    /**
     * 新增支付
     */
    @RequiresPermissions("authentication:pay:add")
    @Log(title = "支付", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增支付")
    public Result<String> add(@RequestBody PaySaveReq paySaveReq) {
        return toAjax(payService.save(Pay.saveBuild(paySaveReq)));
    }

    /**
     * 修改支付
     */
    @RequiresPermissions("authentication:pay:edit")
    @Log(title = "支付", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改支付")
    public Result<String> edit(@PathVariable Long id, @RequestBody PayEditReq payEditReq) {
        return toAjax(payService.updateById(Pay.editBuild(id,payEditReq)));
    }

    /**
     * 删除支付
     */
    @RequiresPermissions("authentication:pay:remove")
    @Log(title = "支付", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除支付")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(payService.removeBatchByIds(ids));
    }
}
