package com.muyu.authentication.controller;

import com.muyu.authentication.service.PaymentService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.payment.domain.Payment;
import com.muyu.payment.domain.req.PaymentEditReq;
import com.muyu.payment.domain.req.PaymentQueryReq;
import com.muyu.payment.domain.req.PaymentSaveReq;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 支付方式Controller
 *
 * @author wan
 * @date 2024-05-29
 */
@Api(tags = "支付方式")
@RestController
@RequestMapping("/payment")
public class PaymentController extends BaseController {
    @Autowired
    private PaymentService paymentService;

    /**
     * 查询支付方式列表
     */
    @ApiOperation("获取支付方式列表")
    @RequiresPermissions("authentication:payment:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Payment>> list(PaymentQueryReq paymentQueryReq) {
        startPage();
        List<Payment> list = paymentService.list(Payment.queryBuild(paymentQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出支付方式列表
     */
    @ApiOperation("导出支付方式列表")
    @RequiresPermissions("authentication:payment:export")
    @Log(title = "支付方式", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Payment payment) {
        List<Payment> list = paymentService.list(payment);
        ExcelUtil<Payment> util = new ExcelUtil<Payment>(Payment.class);
        util.exportExcel(response, list, "支付方式数据");
    }

    /**
     * 获取支付方式详细信息
     */
    @ApiOperation("获取支付方式详细信息")
    @RequiresPermissions("authentication:payment:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Payment> getInfo(@PathVariable("id") Long id) {
        return Result.success(paymentService.getById(id));
    }

    /**
     * 新增支付方式
     */
    @RequiresPermissions("authentication:payment:add")
    @Log(title = "支付方式", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增支付方式")
    public Result<String> add(@RequestBody PaymentSaveReq paymentSaveReq) {
        return toAjax(paymentService.save(Payment.saveBuild(paymentSaveReq)));
    }

    /**
     * 修改支付方式
     */
    @RequiresPermissions("authentication:payment:edit")
    @Log(title = "支付方式", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改支付方式")
    public Result<String> edit(@PathVariable Long id, @RequestBody PaymentEditReq paymentEditReq) {
        return toAjax(paymentService.updateById(Payment.editBuild(id,paymentEditReq)));
    }

    /**
     * 删除支付方式
     */
    @RequiresPermissions("authentication:payment:remove")
    @Log(title = "支付方式", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除支付方式")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(paymentService.removeBatchByIds(ids));
    }
}
